@@ -35,7 +35,7 @@ class KgpgTrustLabel : public QWidget
     Q_OBJECT
 
 public:
-    explicit KgpgTrustLabel(QWidget *parent = Q_NULLPTR);
+    explicit KgpgTrustLabel(QWidget *parent = nullptr);
 
     void setText(const QString &text);
     void setColor(const QColor &color);
@@ -57,7 +57,7 @@ class KgpgKeyInfo : public QDialog, public Ui::kgpgKeyInfo
 {
 	Q_OBJECT
 
-	KgpgKeyInfo() Q_DECL_EQ_DELETE;
+	KgpgKeyInfo() = delete;
 	Q_DISABLE_COPY(KgpgKeyInfo)
 public:
 	KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *parent);
