@@ -29,15 +29,6 @@ static QStringList keyFingerprints(const KGpgKeyNode::List &keys)
 	return ret;
 }
 
-KGpgDelKey::KGpgDelKey(QObject *parent, KGpgKeyNode *key)
-	: KGpgTransaction(parent)
-	, keys({key})
-	, fingerprints(keyFingerprints(keys))
-{
-	setCmdLine();
-	setExpectedFingerprints(fingerprints);
-}
-
 KGpgDelKey::KGpgDelKey(QObject *parent, const KGpgKeyNode::List &keys)
 	: KGpgTransaction(parent)
 	, keys(keys)
@@ -88,9 +79,10 @@ KGpgDelKey::preStart()
 void
 KGpgDelKey::setCmdLine()
 {
-	addArgument(QLatin1String( "--status-fd=1" ));
-	addArgument(QLatin1String( "--command-fd=0" ));
-	addArgument(QLatin1String( "--delete-secret-and-public-key" ));
+	addArguments( { QLatin1String("--status-fd=1"),
+			QLatin1String("--command-fd=0"),
+			QLatin1String("--delete-secret-and-public-key")
+			});
 
 	m_argscount = getProcess()->program().count();
 }
