@@ -173,14 +173,14 @@ beautifyKeyList(const QStringList &keyIds, const KGpgItemModel *model)
 	QString result;
 
 	result.append(QLatin1String("\n"));
-	if (model == Q_NULLPTR) {
+	if (model == nullptr) {
 		result.append(QLatin1String(" ") + keyIds.join(QLatin1String("\n ")));
 	} else {
 		for (const QString &changed : keyIds) {
 			const KGpgKeyNode *node = model->findKeyNode(changed);
 			QString line;
 
-			if (node == Q_NULLPTR) {
+			if (node == nullptr) {
 				line = changed;
 			} else {
 				if (node->getEmail().isEmpty())
@@ -215,7 +215,7 @@ KGpgImport::getDetailedImportMessage(const QStringList &log, const KGpgItemModel
 		resultcodes[rc.at(1)] = rc.at(0).toUInt();
 	}
 
-	QMap<QString, unsigned int>::const_iterator iterend = resultcodes.constEnd();
+	const QMap<QString, unsigned int>::const_iterator iterend = resultcodes.constEnd();
 
 	for (unsigned int flag = 1; flag <= 16; flag <<= 1) {
 		QStringList thischanged;
