@@ -223,14 +223,10 @@ KGpgTransaction::addArgument(const QString &arg)
 	return r;
 }
 
-int
+void
 KGpgTransaction::addArguments(const QStringList &args)
 {
-	int r = d->m_process->program().count();
-
 	*d->m_process << args;
-
-	return r;
 }
 
 void
@@ -262,7 +258,7 @@ KGpgTransaction::insertArguments(const int pos, const QStringList &args)
 	d->m_process->setProgram(tmp);
 
 	int move = args.count();
-	foreach (int *ref, d->m_argRefs) {
+	for (int *ref : qAsConst(d->m_argRefs)) {
 		if (*ref >= pos)
 			*ref += move;
 	}
