@@ -158,6 +158,30 @@ public:
 	 */
 	void kill();
 
+	/**
+	 * @brief add a command line argument to gpg process
+	 * @param arg new argument
+	 * @returns the position of the new argument
+	 *
+	 * This is a convenience function that allows adding one additional
+	 * argument to the command line of the process. This must be called
+	 * before start() is called. Usually you will call this from your
+	 * constructor.
+	 */
+	int addArgument(const QString &arg);
+	/**
+	 * @brief insert an argument at the given position
+	 * @param pos position to insert at
+	 * @param arg new argument
+	 */
+	void insertArgument(const int pos, const QString &arg);
+	/**
+	 * @brief insert arguments at the given position
+	 * @param pos position to insert at
+	 * @param args new arguments
+	 */
+	void insertArguments(const int pos, const QStringList &args);
+
 signals:
 	/**
 	 * @brief Emitted when the operation was completed.
@@ -370,45 +394,22 @@ protected:
 	 * @warning Never free this object!
 	 */
 	GPGProc *getProcess();
-	/**
-	 * @brief add a command line argument to gpg process
-	 * @param arg new argument
-	 * @returns the position of the new argument
-	 *
-	 * This is a convenience function that allows adding one additional
-	 * argument to the command line of the process. This must be called
-	 * before start() is called. Usually you will call this from your
-	 * constructor.
-	 */
-	int addArgument(const QString &arg);
 	/**
 	 * @brief add command line arguments to gpg process
 	 * @param args new arguments
-	 * @returns the position of the first argument added
 	 *
 	 * This is a convenience function that allows adding additional
 	 * arguments to the command line of the process. This must be called
 	 * before start() is called.
 	 */
-	int addArguments(const QStringList &args);
+	void addArguments(const QStringList &args);
+
 	/**
 	 * @brief replace the argument at the given position
 	 * @param pos position of old argument
 	 * @param arg new argument
 	 */
 	void replaceArgument(const int pos, const QString &arg);
-	/**
-	 * @brief insert an argument at the given position
-	 * @param pos position to insert at
-	 * @param arg new argument
-	 */
-	void insertArgument(const int pos, const QString &arg);
-	/**
-	 * @brief insert arguments at the given position
-	 * @param pos position to insert at
-	 * @param args new arguments
-	 */
-	void insertArguments(const int pos, const QStringList &args);
 	/**
 	 * @brief make sure the reference to a specific argument is kept up to date
 	 * @param ref the value where the position is stored
